# Pysmells

**pysmells** é um pacote em python para analisa vunerabilidades de programas em python.

## Dependências
**Python 3.6** ou posterior

Pacotes: **pandas**, **OS**


## Começando o uso
Você vai precisar instalar o pacote **pacotepypi**, para isso basta executar:
```
pip install pysmells
```
